==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/common/item/equipment/tool/SoulscribeItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.equipment.tool;

import org.jetbrains.annotations.NotNull;

import vazkii.botania.api.BotaniaAPI;
import vazkii.botania.common.item.equipment.tool.manasteel.ManasteelSwordItem;

import java.util.function.Consumer;
import net.minecraft.class_1268;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1560;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;

public class SoulscribeItem extends ManasteelSwordItem {

	public SoulscribeItem(class_1793 props) {
		super(BotaniaAPI.instance().getManasteelItemTier(), 3, -1.25F, props);
	}

	@Override
	public boolean method_7873(class_1799 stack, class_1309 target, @NotNull class_1309 attacker) {
		if (!target.field_6002.field_9236
				&& target instanceof class_1560
				&& attacker instanceof class_1657 player) {
			target.method_5643(class_1282.method_5532(player), 20);
		}

		stack.method_7956(1, attacker, e -> e.method_20236(class_1268.field_5808));
		return true;
	}

	@Override
	public void method_7888(class_1799 stack, class_1937 world, class_1297 player, int slot, boolean selected) {}

	@Override
	public <T extends class_1309> int damageItem(class_1799 stack, int amount, T entity, Consumer<T> onBroken) {
		return amount;
	}
}

==> Botania-1.20.1-449-FABRIC-20250624.054451-29-sources.jar: vazkii/botania/common/item/equipment/tool/SoulscribeItem.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.common.item.equipment.tool;

import org.jetbrains.annotations.NotNull;

import vazkii.botania.api.BotaniaAPI;
import vazkii.botania.common.item.equipment.tool.manasteel.ManasteelSwordItem;

import java.util.function.Consumer;
import net.minecraft.class_1268;
import net.minecraft.class_1297;
import net.minecraft.class_1309;
import net.minecraft.class_1560;
import net.minecraft.class_1657;
import net.minecraft.class_1799;
import net.minecraft.class_1937;

public class SoulscribeItem extends ManasteelSwordItem {

	public SoulscribeItem(class_1793 props) {
		super(BotaniaAPI.instance().getManasteelItemTier(), 3, -1.25F, props);
	}

	@Override
	public boolean method_7873(class_1799 stack, class_1309 target, @NotNull class_1309 attacker) {
		if (!target.method_37908().field_9236
				&& target instanceof class_1560
				&& attacker instanceof class_1657 player) {
			target.method_5643(player.method_48923().method_48802(player), 20);
		}

		stack.method_7956(1, attacker, e -> e.method_20236(class_1268.field_5808));
		return true;
	}

	@Override
	public void method_7888(class_1799 stack, class_1937 world, class_1297 player, int slot, boolean selected) {}

	@Override
	public <T extends class_1309> int damageItem(class_1799 stack, int amount, T entity, Consumer<T> onBroken) {
		return amount;
	}
}
